/*****************************************************************************
*  @file     kimclient.h                                                     *
*  @brief    kim API                                                         *
*                                                                            *
*  @author   付焕章                                                           *
*  @email    fuhuanzhang@kylinos.cn                                          *
*  @version  1.2.1                                                           *
*  @date     2021-07-01                                                      *
*                                                                            *
*----------------------------------------------------------------------------*
*****************************************************************************/
#ifndef _KIMAPI_H
#define _KIMAPI_H

#ifdef __cplusplus 
extern "C"{ 
#endif

/*
 * @brief 检查终端是否已经加域
 * @return 检查结果
 * @retval 0 未加域
 * @retval 1 已加域
 */
int check_domain_installed();

/*
 * @brief 当前用户是否域用户
 * @retval 0 本地用户
 * @retval 1 域用户
 */
int is_domain_user(const char *name);

/*
 * @brief 获取用户登录日志
 * @param out users 非空指针，*user会指向一个json字符串
 * @return 返回记录数
 * @par 示例:
 * @code
 * char *userlogs = NULL;
 * int ret = get_user_logs_data(&userlogs);
 * if(ret >= 0){
 *     //do something
 *     free(userlogs)
 * }
 * @retval <0 调用失败
 * @retval >=0 获取成功，需要free(*user)
 */
int get_user_logs_data(char **users);

/*
 * @brief 获取当前登录域用户
 * @param out users 非空指针，*user会指向一个json字符串。 "[{"uid":"zhangsan","name":"张三"},{"uid":"lisi","name":"李四"}]"
 * @par 示例:
 * @code
 * char *userlogs = NULL;
 * int ret = get_domain_logins_data(&userlogs);
 * if(ret >= 0){
 *     //do something
 *     free(userlogs)
 * }
 * @retval <0 调用失败
 * @retval >=0 获取成功，需要free(*user)
 */
int get_domain_logins_data(char **users);

/*
 * @brief 供通讯框架调用，获取用户登录日志请调用get_user_logs_data
 */
int get_user_logs(char **users);
/*
 * @brief 供通讯框架调用，获取当前登录用户请调用get_domain_logins_data
 */
int get_domain_logins(char **users);

/*
 * @brief 判断用户是否具有sudo权限
 * @param in uname 用户名
 * @retval 1 用户在sudo组
 * @retval 0 用户不在sudo组
 * @retval <0 发生错误
 */
int check_sudo_with_uname(const char *uname);

/*
 * @brief 判断用户是否具有sudo权限
 * @param in uid 用户uid
 * @seeAlso check_sudo_with_uname
 */
int check_sudo_with_uid(long uid);

/*
 * @brief 判断加域是否异常
 * @retval 1 加域异常，需恢复
 * @retval 0 没有异常
 */
int kim_check_crash();

/*
 * @brief 获取登录失败域用户记录
 * @param out authlogs 非空指针，指向json字符串
 * @par 示例:
 * @code
 * char *str = NULL;
 * int ret = get_failed_logins(&str);
 * if(ret >= 0){
 *     //do something
 *     free(str)
 * }
 */
int get_failed_logins(char **authlogs);

#ifdef __cplusplus
}
#endif
#endif
